@@ -288,7 +288,7 @@ class ObjectClerk:
 
     @mutate_client_exceptions
     def _upload_object(
-        self, bytes_obj: bytes, bucket: str, object_key: str, content_type: str
+        self, bytes_obj: bytes, bucket: str, object_key: str, content_type: str, metadata: dict
     ) -> None:
         """
         Executes the boto3.client.upload_fileobj function with ClientError exceptions
@@ -296,6 +296,8 @@ class ObjectClerk:
         :param bucket: Bucket to upload the object to
         :param object_key: Key of the object in the bucket to upload to
         :param bytes_obj: bytes to upload
+        :param content_type: Content type of the file to be uploaded.  Will be added to the ExtraArgs as Content-Type
+        :param metadata: metadata for the file to be uploaded.  Will be added to the ExtraArgs as Metadata
         :return: None
         """
         logger.debug(f"Attempting object upload: bucket={bucket}, object_key={object_key}")
@@ -304,7 +306,7 @@ class ObjectClerk:
             Bucket=bucket,
             Key=object_key,
             Config=UPLOAD_CONFIG,
-            ExtraArgs={"ContentType": content_type},
+            ExtraArgs={"ContentType": content_type, "Metadata": metadata},
         )
 
     @retry(ObjectVerificationException, **CHECKSUM_RETRY_CONFIG)
@@ -315,6 +317,7 @@ class ObjectClerk:
         object_key: str,
         verify_checksum: bool = True,
         content_type: str = "application/octet-stream",
+        metadata: dict = None,
     ) -> None:
         """
         Uploads a data to the specified bucket and object key retrying connection errors according to instance
@@ -324,9 +327,12 @@ class ObjectClerk:
         :param object_key: Object Key in the bucket for the object after upload
         :param verify_checksum: Boolean indicator of whether to verify the checksum of the uploaded file matches
         what is in the S3 bucket
+        :param content_type: Content type of the file to be uploaded.  Will be added to the ExtraArgs as Content-Type
+        :param metadata: metadata for the file to be uploaded.  Will be added to the ExtraArgs as Metadata
         :return: None
         :raises: ObjectVerificationException, ObjectSaveException, ObjectClerkException, ObjectClerkServerAuthException
         """
+        metadata = metadata or {}
         bytes_obj = self._data_to_bytes(object_data)
         # get checksum before boto operations
         checksum = self._get_object_checksum(bytes_obj)
@@ -339,6 +345,7 @@ class ObjectClerk:
                 "bucket": bucket,
                 "object_key": object_key,
                 "content_type": content_type,
+                "metadata": metadata,
             },
             **self.retry_config,
         )
