@@ -18,7 +18,7 @@ import pytest
 from object_clerk import ObjectClerk
 from object_clerk import ObjectNotFoundException
 from object_clerk import ObjectSaveException
-from object_clerk.clerk import MULTIPART_THRESHOLD
+from object_clerk.config import MULTIPART_THRESHOLD
 
 
 """
